﻿<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <xsl:output method="html" encoding="utf-8" indent="yes"/>

  <xsl:template match="/">
    <html xmlns="http://www.w3.org/1999/xhtml">
      <head>
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
		<!--<link rel="stylesheet" type="text/css" media="screen, print" href="default.css"/>-->
        <title><xsl:value-of select="*/internal-name"/></title>
      </head>
      <body>
        <xsl:apply-templates/>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="action">
    <h1>
      Action: <xsl:value-of select="internal-name"/>
			(<xsl:for-each select="parameters/object">
				<span><xsl:value-of select="."/></span>
				<xsl:if test="position() != last()">
					<span>,</span>
				</xsl:if>
			</xsl:for-each>)
    </h1>
		<xsl:apply-templates select="preconditions"/>
		<xsl:apply-templates select="invariants"/>
		<xsl:apply-templates select="postconditions"/>
		<xsl:apply-templates select="exec"/>
  </xsl:template>
  
  <xsl:template match="preconditions">
    <h2>Preconditions</h2>
    <ul>
      <xsl:apply-templates/>
    </ul>
  </xsl:template>
  
  <xsl:template match="invariants">
    <h2>Invariants</h2>
    <ul>
      <xsl:apply-templates/>
    </ul>
  </xsl:template>
  
  <xsl:template match="postconditions">
    <h2>Postconditions</h2>
    <ul>
      <xsl:apply-templates/>
    </ul>
  </xsl:template>
  
  <xsl:template match="condition">
    <li>
      <a>
        <xsl:choose>
          <xsl:when test="starts-with(name, '!')">
            <xsl:attribute name="href">../../conditions/condition/<xsl:value-of select="substring-after(name, '!')"/>.xml</xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="href">../../conditions/condition/<xsl:value-of select="name"/>.xml</xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="name"/>
      </a>
      <span>(</span>
      <xsl:for-each select="param">
        <span><xsl:value-of select="."/></span>
        <xsl:if test="position() != last()">
          <span>,</span>
        </xsl:if>
      </xsl:for-each>
      <span>)</span>
    </li>
  </xsl:template>

  <xsl:template match="exec">
    <h2>Execution</h2>
    <p>
      <xsl:value-of select="method"/><span>(</span><xsl:apply-templates select="exec-parameters"/><span>)</span>
    </p>
  </xsl:template>
  
  <xsl:template match="exec-parameters">
    <xsl:for-each select="object">
      <span><xsl:value-of select="."/></span>
      <xsl:if test="position() != last()">
        <span>,</span>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>
  
</xsl:stylesheet>
